@@ -1,8 +1,9 @@
-from django.shortcuts import render_to_response
+from django.shortcuts import render
 from styleguide.utils import StyleguideLoader
 
 def index(request):
     styleguide_loader = StyleguideLoader()
     styleguide_components = styleguide_loader.get_styleguide_components()
 
-    return render_to_response("styleguide/index.html", { 'styleguide': styleguide_components })
\ No newline at end of file
+    context = { 'styleguide': styleguide_components }
+    return render(request, "styleguide/index.html", context)
\ No newline at end of file
